"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.executeMarkCLISessionInactive = exports.executeMarkCLISessionActiveHeartbeat = exports.executeCreateNewSchemaMutation = exports.executeUpsertAppForSiteMutation = exports.fetchAppSchemaQuery = exports.executeAckCLISessionEventMutation = exports.fetchCLISessionQuery = exports.executeCreateCLISessionEventMutation = exports.executeUpdateCLISessionMetadataMutation = exports.executeCreateCLISessionMutation = exports.fetchPersistedQueryQuery = exports.fetchListPersistedQueries = exports.executeCreateApiTokenMutation = exports.executeCreatePersistedQueryMutation = exports.executeCreateGraphQLSchemaMutation = exports.verifyRequestSignature = exports.verifySignature = void 0;
// GENERATED VIA NETLIFY AUTOMATED DEV TOOLS, EDIT WITH CAUTION!
var buffer_1 = require("buffer");
var crypto_1 = require("crypto");
var https_1 = require("https");
var process_1 = require("process");
var verifySignature = function (input) {
    var secret = input.secret;
    var body = input.body;
    var signature = input.signature;
    if (!signature) {
        console.error("Missing signature");
        return false;
    }
    var sig = {};
    for (var _i = 0, _a = signature.split(","); _i < _a.length; _i++) {
        var pair = _a[_i];
        var _b = pair.split("="), key = _b[0], value = _b[1];
        sig[key] = value;
    }
    if (!sig.t || !sig.hmac_sha256) {
        console.error("Invalid signature header");
        return false;
    }
    var hash = crypto_1.default
        .createHmac("sha256", secret)
        .update(sig.t)
        .update(".")
        .update(body)
        .digest("hex");
    if (!crypto_1.default.timingSafeEqual(Buffer.from(hash, "hex"), Buffer.from(sig.hmac_sha256, "hex"))) {
        console.error("Invalid signature");
        return false;
    }
    if (parseInt(sig.t, 10) < Date.now() / 1000 - 300 /* 5 minutes */) {
        console.error("Request is too old");
        return false;
    }
    return true;
};
exports.verifySignature = verifySignature;
var httpGet = function (input) {
    var userHeaders = input.headers || {};
    var fullHeaders = __assign(__assign({}, userHeaders), { "Content-Type": "application/json" });
    var timeoutMs = 30000;
    var reqOptions = {
        method: "GET",
        headers: fullHeaders,
        timeout: timeoutMs,
    };
    if (!input.docId) {
        throw new Error("docId is required for GET requests: " + input.operationName);
    }
    var schemaId = input.schemaId || undefined;
    var encodedVariables = encodeURIComponent(input.variables || "null");
    var url = "https://serve.onegraph.com/graphql?app_id=" +
        input.siteId +
        "&doc_id=" +
        input.docId +
        (input.operationName ? "&operationName=" + input.operationName : "") +
        (schemaId ? "&schemaId=" + schemaId : "") +
        "&variables=" +
        encodedVariables;
    var respBody = [];
    return new Promise(function (resolve, reject) {
        var req = https_1.default.request(url, reqOptions, function (res) {
            if (res.statusCode && (res.statusCode < 200 || res.statusCode > 299)) {
                return reject(new Error("Netlify Graph return non-OK HTTP status code" + res.statusCode));
            }
            res.on("data", function (chunk) { return respBody.push(chunk); });
            res.on("end", function () {
                var resString = buffer_1.default.Buffer.concat(respBody).toString();
                resolve(resString);
            });
        });
        req.on("error", function (error) {
            console.error("Error making request to Netlify Graph:", error);
        });
        req.on("timeout", function () {
            req.destroy();
            reject(new Error("Request to Netlify Graph timed out"));
        });
        req.end();
    });
};
var httpPost = function (input) {
    var reqBody = input.body || null;
    var userHeaders = input.headers || {};
    var headers = __assign(__assign({}, userHeaders), { "Content-Type": "application/json", "Content-Length": reqBody.length });
    var timeoutMs = 30000;
    var reqOptions = {
        method: "POST",
        headers: headers,
        timeout: timeoutMs,
    };
    var schemaId = input.schemaId || undefined;
    var url = "https://serve.onegraph.com/graphql?app_id=" +
        input.siteId +
        (schemaId ? "&schemaId=" + schemaId : "");
    var respBody = [];
    return new Promise(function (resolve, reject) {
        var req = https_1.default.request(url, reqOptions, function (res) {
            if (res.statusCode && (res.statusCode < 200 || res.statusCode > 299)) {
                return reject(new Error("Netlify Graph return non-OK HTTP status code" + res.statusCode));
            }
            res.on("data", function (chunk) { return respBody.push(chunk); });
            res.on("end", function () {
                var resString = buffer_1.default.Buffer.concat(respBody).toString();
                resolve(resString);
            });
        });
        req.on("error", function (error) {
            console.error("Error making request to Netlify Graph:", error);
        });
        req.on("timeout", function () {
            req.destroy();
            reject(new Error("Request to Netlify Graph timed out"));
        });
        req.write(reqBody);
        req.end();
    });
};
var fetchNetlifyGraph = function fetchNetlifyGraph(input) {
    var docId = input.doc_id;
    var operationName = input.operationName;
    var variables = input.variables;
    var options = input.options || {};
    var accessToken = options.accessToken;
    var siteId = options.siteId || process_1.default.env.SITE_ID;
    var httpMethod = input.fetchStrategy === "GET" ? httpGet : httpPost;
    var response = httpMethod({
        siteId: siteId,
        docId: docId,
        query: input.query,
        headers: {
            Authorization: accessToken ? "Bearer " + accessToken : "",
        },
        variables: variables,
        operationName: operationName,
    });
    return response.then(function (result) { return JSON.parse(result); });
};
var verifyRequestSignature = function (request, options) {
    var event = request.event;
    var secret = options.webhookSecret || process_1.default.env.NETLIFY_GRAPH_WEBHOOK_SECRET;
    var signature = event.headers["x-netlify-graph-signature"];
    var body = event.body;
    if (!secret) {
        console.error("NETLIFY_GRAPH_WEBHOOK_SECRET is not set, cannot verify incoming webhook request");
        return false;
    }
    return (0, exports.verifySignature)({ secret: secret, signature: signature, body: body || "" });
};
exports.verifyRequestSignature = verifyRequestSignature;
var executeCreateGraphQLSchemaMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation CreateGraphQLSchemaMutation($input: OneGraphCreateGraphQLSchemaInput!) {\n  oneGraph {\n    createGraphQLSchema(input: $input) {\n      graphQLSchema {\n        id\n        externalGraphQLSchemas {\n          nodes {\n            id\n            endpoint\n            service\n            createdAt\n            updatedAt\n          }\n        }\n        parentGraphQLSchemaId\n        salesforceSchema {\n          id\n          createdAt\n          updatedAt\n        }\n        services {\n          slug\n        }\n        updatedAt\n        createdAt\n        appId\n      }\n    }\n  }\n}",
        operationName: "CreateGraphQLSchemaMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeCreateGraphQLSchemaMutation = executeCreateGraphQLSchemaMutation;
var executeCreatePersistedQueryMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation CreatePersistedQueryMutation($nfToken: String!, $cacheStrategy: OneGraphPersistedQueryCacheStrategyArg, $allowedOperationNames: [String!]!, $fallbackOnError: Boolean!, $freeVariables: [String!]!, $query: String!, $tags: [String!]!, $description: String, $appId: String!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    createPersistedQuery(\n      input: {query: $query, appId: $appId, cacheStrategy: $cacheStrategy, allowedOperationNames: $allowedOperationNames, fallbackOnError: $fallbackOnError, freeVariables: $freeVariables, tags: $tags, description: $description}\n    ) {\n      persistedQuery {\n        id\n        allowedOperationNames\n        description\n        fixedVariables\n        freeVariables\n        query\n        tags\n      }\n    }\n  }\n}",
        operationName: "CreatePersistedQueryMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeCreatePersistedQueryMutation = executeCreatePersistedQueryMutation;
var executeCreateApiTokenMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation CreateApiTokenMutation($input: OneGraphCreateApiTokenTokenInput!, $nfToken: String!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    createApiToken(input: $input) {\n      accessToken {\n        token\n        userAuths {\n          service\n          foreignUserId\n          scopes\n        }\n        appId\n        expireDate\n        name\n        netlifyId\n        anchor\n      }\n    }\n  }\n}",
        operationName: "CreateApiTokenMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeCreateApiTokenMutation = executeCreateApiTokenMutation;
var fetchListPersistedQueries = function (variables, options) {
    return fetchNetlifyGraph({
        query: "query ListPersistedQueries($appId: String!, $first: Int!, $after: String, $tags: [String!]!) {\n  oneGraph {\n    app(id: $appId) {\n      id\n      persistedQueries(first: $first, after: $after, tags: $tags) {\n        pageInfo {\n          hasNextPage\n          endCursor\n        }\n        nodes {\n          id\n          query\n          fixedVariables\n          freeVariables\n          allowedOperationNames\n          tags\n          description\n        }\n      }\n    }\n  }\n}",
        operationName: "ListPersistedQueries",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.fetchListPersistedQueries = fetchListPersistedQueries;
var fetchPersistedQueryQuery = function (variables, options) {
    return fetchNetlifyGraph({
        query: "query PersistedQueryQuery($nfToken: String!, $appId: String!, $id: String!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    persistedQuery(appId: $appId, id: $id) {\n      id\n      query\n      allowedOperationNames\n      description\n      freeVariables\n      fixedVariables\n      tags\n    }\n  }\n}",
        operationName: "PersistedQueryQuery",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.fetchPersistedQueryQuery = fetchPersistedQueryQuery;
var executeCreateCLISessionMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation CreateCLISessionMutation($nfToken: String!, $appId: String!, $name: String!, $metadata: JSON) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    createNetlifyCliSession(\n      input: {appId: $appId, name: $name, metadata: $metadata}\n    ) {\n      session {\n        id\n        appId\n        netlifyUserId\n        name\n        cliHeartbeatIntervalMs\n      }\n    }\n  }\n}",
        operationName: "CreateCLISessionMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeCreateCLISessionMutation = executeCreateCLISessionMutation;
var executeUpdateCLISessionMetadataMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation UpdateCLISessionMetadataMutation($nfToken: String!, $sessionId: String!, $metadata: JSON!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    updateNetlifyCliSession(input: {id: $sessionId, metadata: $metadata}) {\n      session {\n        id\n        name\n        metadata\n        cliHeartbeatIntervalMs\n      }\n    }\n  }\n}",
        operationName: "UpdateCLISessionMetadataMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeUpdateCLISessionMetadataMutation = executeUpdateCLISessionMetadataMutation;
var executeCreateCLISessionEventMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation CreateCLISessionEventMutation($nfToken: String!, $sessionId: String!, $payload: JSON!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    createNetlifyCliTestEvent(\n      input: {data: {payload: $payload}, sessionId: $sessionId}\n    ) {\n      event {\n        id\n        createdAt\n        sessionId\n      }\n    }\n  }\n}",
        operationName: "CreateCLISessionEventMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeCreateCLISessionEventMutation = executeCreateCLISessionEventMutation;
var fetchCLISessionQuery = function (variables, options) {
    return fetchNetlifyGraph({
        query: "query CLISessionQuery($nfToken: String!, $sessionId: String!, $first: Int!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    __typename\n    netlifyCliSession(id: $sessionId) {\n      appId\n      createdAt\n      id\n      cliHeartbeatIntervalMs\n      events(first: $first) {\n        __typename\n        createdAt\n        id\n        sessionId\n        ... on OneGraphNetlifyCliSessionLogEvent {\n          id\n          message\n          sessionId\n          createdAt\n        }\n        ... on OneGraphNetlifyCliSessionTestEvent {\n          id\n          createdAt\n          payload\n          sessionId\n        }\n      }\n      lastEventAt\n      metadata\n      name\n      netlifyUserId\n    }\n  }\n}",
        operationName: "CLISessionQuery",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.fetchCLISessionQuery = fetchCLISessionQuery;
var executeAckCLISessionEventMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation AckCLISessionEventMutation($nfToken: String!, $sessionId: String!, $eventIds: [String!]!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    ackNetlifyCliEvents(input: {eventIds: $eventIds, sessionId: $sessionId}) {\n      events {\n        id\n      }\n    }\n  }\n}",
        operationName: "AckCLISessionEventMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeAckCLISessionEventMutation = executeAckCLISessionEventMutation;
var fetchAppSchemaQuery = function (variables, options) {
    return fetchNetlifyGraph({
        query: "query AppSchemaQuery($nfToken: String!, $appId: String!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    app(id: $appId) {\n      graphQLSchema {\n        appId\n        createdAt\n        id\n        services {\n          friendlyServiceName\n          logoUrl\n          service\n          slug\n          supportsCustomRedirectUri\n          supportsCustomServiceAuth\n          supportsOauthLogin\n        }\n        updatedAt\n      }\n    }\n  }\n}",
        operationName: "AppSchemaQuery",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.fetchAppSchemaQuery = fetchAppSchemaQuery;
var executeUpsertAppForSiteMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation UpsertAppForSiteMutation($nfToken: String!, $siteId: String!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    upsertAppForNetlifySite(input: {netlifySiteId: $siteId}) {\n      org {\n        id\n        name\n      }\n      app {\n        id\n        name\n        corsOrigins\n        customCorsOrigins {\n          friendlyServiceName\n          displayName\n          encodedValue\n        }\n      }\n    }\n  }\n}",
        operationName: "UpsertAppForSiteMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeUpsertAppForSiteMutation = executeUpsertAppForSiteMutation;
var executeCreateNewSchemaMutation = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation CreateNewSchemaMutation($nfToken: String!, $input: OneGraphCreateGraphQLSchemaInput!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    createGraphQLSchema(input: $input) {\n      app {\n        graphQLSchema {\n          id\n        }\n      }\n      graphqlSchema {\n        id\n        services {\n          friendlyServiceName\n          logoUrl\n          service\n          slug\n          supportsCustomRedirectUri\n          supportsCustomServiceAuth\n          supportsOauthLogin\n        }\n      }\n    }\n  }\n}",
        operationName: "CreateNewSchemaMutation",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeCreateNewSchemaMutation = executeCreateNewSchemaMutation;
var executeMarkCLISessionActiveHeartbeat = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation MarkCLISessionActiveHeartbeat($nfToken: String!, $id: String!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    updateNetlifyCliSession(input: {status: ACTIVE, id: $id}) {\n      session {\n        id\n        status\n        createdAt\n        updatedAt\n        cliHeartbeatIntervalMs\n      }\n    }\n  }\n}",
        operationName: "MarkCLISessionActiveHeartbeat",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeMarkCLISessionActiveHeartbeat = executeMarkCLISessionActiveHeartbeat;
var executeMarkCLISessionInactive = function (variables, options) {
    return fetchNetlifyGraph({
        query: "mutation MarkCLISessionInactive($nfToken: String!, $id: String!) {\n  oneGraph(auths: {netlifyAuth: {oauthToken: $nfToken}}) {\n    updateNetlifyCliSession(input: {status: INACTIVE, id: $id}) {\n      session {\n        id\n        status\n        createdAt\n        updatedAt\n        cliHeartbeatIntervalMs\n      }\n    }\n  }\n}",
        operationName: "MarkCLISessionInactive",
        variables: variables,
        options: options,
        fetchStrategy: "POST",
    });
};
exports.executeMarkCLISessionInactive = executeMarkCLISessionInactive;
/**
 * The generated NetlifyGraph library with your operations
 */
var functions = {
    /**
     * Create a GraphQL Schema by specifying its inputs (services, external GraphQL schemas, etc.)
     */
    executeCreateGraphQLSchemaMutation: exports.executeCreateGraphQLSchemaMutation,
    /**
     * Create a token belonging to a specific siteId to persist operations and create GraphQL schemas later
     */
    executeCreateApiTokenMutation: exports.executeCreateApiTokenMutation,
    /**
     * Create a persisted operations doc to be later retrieved, usually from a GUI
     */
    executeCreatePersistedQueryMutation: exports.executeCreatePersistedQueryMutation,
    /**
     * Fetch a paginated list of persisted queries belonging to an app
     */
    fetchListPersistedQueries: exports.fetchListPersistedQueries,
    /**
     * Fetch a persisted doc belonging to appId by its id
     */
    fetchPersistedQueryQuery: exports.fetchPersistedQueryQuery,
    /**
     * Register a new CLI session with OneGraph
     */
    executeCreateCLISessionMutation: exports.executeCreateCLISessionMutation,
    /**
     * Update the CLI session with new metadata (e.g. the latest docId) by its id
     */
    executeUpdateCLISessionMetadataMutation: exports.executeUpdateCLISessionMetadataMutation,
    /**
     * Create a new event for a CLI session to consume
     */
    executeCreateCLISessionEventMutation: exports.executeCreateCLISessionEventMutation,
    /**
     * Fetch a single CLI session by its id
     */
    fetchCLISessionQuery: exports.fetchCLISessionQuery,
    /**
     * Acknowledge CLI events that have been processed and delete them from the upstream queue
     */
    executeAckCLISessionEventMutation: exports.executeAckCLISessionEventMutation,
    /**
     * Fetch the schema metadata for a site (enabled services, id, etc.)
     */
    fetchAppSchemaQuery: exports.fetchAppSchemaQuery,
    /**
     * If a site does not exists upstream in OneGraph for the given site, create it
     */
    executeUpsertAppForSiteMutation: exports.executeUpsertAppForSiteMutation,
    /**
     * Create a new schema in OneGraph for the given site with the specified metadata (enabled services, etc.)
     */
    executeCreateNewSchemaMutation: exports.executeCreateNewSchemaMutation,
    /**
     * Mark a CLI session as active and update the session's heartbeat
     */
    executeMarkCLISessionActiveHeartbeat: exports.executeMarkCLISessionActiveHeartbeat,
    /**
     * Mark a CLI session as inactive
     */
    executeMarkCLISessionInactive: exports.executeMarkCLISessionInactive,
};
exports.default = functions;
var handler = function () {
    // return a 401 json response
    return {
        statusCode: 401,
        body: JSON.stringify({
            message: "Unauthorized",
        }),
    };
};
exports.handler = handler;
//# sourceMappingURL=generatedOneGraphClient.js.map